@@ -3,23 +3,28 @@ https://github.com/tiddlyweb/chrjs/raw/master/users.js
 ***/
 //{{{
 // chrjs users extension
-// v0.4.0
+// v0.5.0
 //
 // requires tiddlywebplugins.socialusers
 // http://pypi.python.org/pypi/tiddlywebplugins.socialusers
 
-(function($) {
+/*jslint vars: true */
+/*global jQuery, tiddlyweb */
 
-tiddlyweb.routes.users = "{host}/users";
-tiddlyweb.routes.user = "{host}/users/{username}";
+(function($, tw) {
 
-tiddlyweb.User = function(username, password, host) {
-	tiddlyweb.Resource.apply(this, ["user", host]);
+"use strict";
+
+tw.routes.users = "{host}/users";
+tw.routes.user = "{host}/users/{username}";
+
+tw.User = function(username, password, host) {
+	tw.Resource.apply(this, ["user", host]);
 	this.username = username;
 	this.password = password;
 };
-tiddlyweb.User.prototype = new tiddlyweb.Resource();
-$.extend(tiddlyweb.User.prototype, {
+tw.User.prototype = new tw.Resource();
+$.extend(tw.User.prototype, {
 	create: function(callback, errback) {
 		var uri = this.route().split("/"); // XXX: hacky!?
 		uri.pop();
@@ -33,7 +38,7 @@ $.extend(tiddlyweb.User.prototype, {
 			url: uri,
 			type: "POST",
 			contentType: "application/json",
-			data: $.toJSON(data),
+			data: JSON.stringify(data),
 			success: callback,
 			error: function(xhr, error, exc) {
 				errback(xhr, error, exc, self);
@@ -48,5 +53,5 @@ $.extend(tiddlyweb.User.prototype, {
 	data: ["password", "old_password"]
 });
 
-})(jQuery);
+}(jQuery, tiddlyweb));
 //}}}
